@@ -1,8 +1,3 @@
-
-
-
-
-
 #' DET Curve calculation
 #'
 #' From a response and predictors, the function calculates the DET curve for each pair (response, predictor). Optionally, it can compute this curve with a Confidence Interval (CI).
@@ -78,6 +73,13 @@ detc = function(response = NULL,
     response = as.factor(response)
   }
   
+  if (!is.matrix(predictors)) {
+    if(is.vector(predictors)) {
+      ## if it's a vector, just change it to matrix with one column
+      predictors = matrix(predictors, ncol = 1)
+    }
+  }
+  
   assertDetCurveParameters(response, predictors, ncores, conf, dets, names, nboot)
   if (!is.null(dets)) {
     if (isDetCurveAlreadyComputedForCI(dets, conf)) {
